@@ -23,36 +23,45 @@ import relex.concurrent.RelexContext;
 import relex.feature.FeatureNode;
 import relex.feature.SemanticView;
 
-public class PrepositionLinkAlg extends TemplateMatchingAlg
+/**
+ * XXX It would be more elegant if a new kind of markup was invented for this,
+ * and TemplateActionAlg did the heavy lifting here. That way, we could 
+ * obsolete this class.  i.e. we need some way of saying "get the string
+ * of this thing" and having TemplateActionAlg do the string manipulation.
+ * Because, really, this alg doesn't really do anything sophisticatted, at all.
+ */
+public class PrepositionLinkAlg extends TemplateActionAlg
 {
-	protected void applyTo(FeatureNode modifiedRef,
+	private void applyTo(FeatureNode modifiedRef,
 	                       FeatureNode prepObj,
 	                       FeatureNode prepStringValue,
 	                       FeatureNode prepStringSource)
 	{
 		String prep = prepStringValue.getValue();
 		FeatureNode modifiedLinks = modifiedRef.getOrMake("prep-links");
-		FeatureNode modifiedLinkSources = modifiedRef.getOrMake("linkSources");
 
 		FeatureNode existingPrepObj = modifiedLinks.get(prep);
-		// add prep to links, converting to a group if necessary
-		if (existingPrepObj == null) {
-			// System.err.println("PREP does not exist");
+
+		// Add prep to links, converting to a group if necessary
+		if (existingPrepObj == null)
+		{
+			// System.err.println("Debug: PREP does not exist");
 			modifiedLinks.set(prep, prepObj);
-			modifiedLinkSources.set(prep, prepStringSource);
-		} else {
-			// System.err.println("PREP exists");
+		}
+		else
+		{
+			// System.err.println("Debug: PREP exists");
 
 			// add a new indexed-prep
 			int i = 2;
 			String indexedPrep = prep + i;
 			// Find an unused index
-			while (modifiedLinks.get(indexedPrep) != null) {
+			while (modifiedLinks.get(indexedPrep) != null)
+			{
 				i++;
 				indexedPrep = prep + i;
 			}
 			modifiedLinks.set(indexedPrep, prepObj);
-			modifiedLinkSources.set(indexedPrep, prepStringSource);
 		}
 	}
 
@@ -65,25 +74,34 @@ public class PrepositionLinkAlg extends TemplateMatchingAlg
 		FeatureNode prep_source = getTemplate().val("prep_source", vars);
 
 		/*
-		 * System.err.println("\nCalling PrepositionLinkAlg:");
-		 * System.err.println("Modified word: " + modified.get("str"));
-		 * System.err.println("prep: " + prepStringValue);
-		 * System.err.println("prep obj: " + prep_obj.get("name"));
-		 * System.err.println("prep source: " + prep_source.get("str"));
+		 * System.err.println("\nDebug: Calling PrepositionLinkAlg:");
+		 * System.err.println("\tModified word: " + modified.get("str"));
+		 * System.err.println("\tprep: " + prepStringValue);
+		 * System.err.println("\tprep obj: " + prep_obj.get("name"));
+		 * System.err.println("\tprep source: " + prep_source.get("str"));
 		 */
 
-		if (SemanticView.isGroup(modified)) {
+		if (SemanticView.isGroup(modified))
+		{
 			// If the modified object is a group, apply prep to each of its
 			// elements
 			Iterator<FeatureNode> i = SemanticView.groupMemberIterator(modified);
-			while (i.hasNext()) {
+			while (i.hasNext())
+			{
 				applyTo(i.next().get("ref"), prep_obj, prepStringValue, prep_source);
 			}
 
-		} else {
+		}
+		else
+		{
 			// Otherwise, apply to just the one element.
 			applyTo(modified.get("ref"), prep_obj, prepStringValue, prep_source);
 		}
+
+		// The superclass is TemplateActionAlg -- go and run its apply method. 
+		// That allows us to perform some additional bits & teeaks as needed,
+		// and lessesn the difference between this alg and the emplateActionAlg.
+		super.applyTo(node, context, vars);
 	}
 }
 
