@@ -43,15 +43,6 @@ public class DocSplitterFallbackImpl implements DocSplitter
 		return true;
 	}
 
-	/**
-	 * Returns false if break is unacceptable. Used to prevent overzelous
-	 * sentence detectors which have recognizable idiosyncracies
-	 */
-	public boolean acceptableBreak(String s, int start, int end)
-	{
-		return false;
-	}
-
 	/**
 	 * Add more text to the buffer.
 	 * This allows this class to be used in FIFO mode: text is added with
